@@ -1,20 +1,21 @@
 import os
-
 import matplotlib.font_manager as fm
 import matplotlib.pyplot as plt
+import pkg_resources
 
 from .cartopy_helper import cartopy_plot_tickmarks
 from .figsizes_set import figsizes, subplot_labels
 
-current_dir = os.path.dirname(os.path.abspath(__file__))
+# 获取资源目录的路径，假设 'fonts' 和 'styles' 目录已经在你的包数据中
+font_dir = pkg_resources.resource_filename(__name__, "fonts")
+style_dir = pkg_resources.resource_filename(__name__, "styles")
 
-font_dir = os.path.join(current_dir, "font")
+# 加载字体
 font_files = fm.findSystemFonts(fontpaths=[font_dir])
 for font_file in font_files:
     fm.fontManager.addfont(font_file)
 
-# register all mplstyle
-style_dir = os.path.join(current_dir, "styles")
+# 注册所有 mplstyle
 stylesheets = {}
 for root, dirs, files in os.walk(style_dir):
     new_stylesheets = plt.style.core.read_style_directory(root)
